@@ -68,6 +68,7 @@ mod tests {
         cargo_binstall = true
         color = true
         disable_default_shorthands = false
+        disable_hints = []
         disable_tools = []
         experimental = true
         go_default_packages_file = "~/.default-go-packages"
@@ -116,6 +117,7 @@ mod tests {
         cargo_binstall
         color
         disable_default_shorthands
+        disable_hints
         disable_tools
         experimental
         go_default_packages_file
