@@ -1,5 +1,6 @@
 use color_eyre::eyre::{eyre, Result};
 use console::style;
+use indoc::formatdoc;
 
 use crate::cli::args::ToolArg;
 use crate::config::Config;
@@ -95,8 +96,13 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 mod tests {
     use std::env;
 
+    use insta::assert_snapshot;
+
+    use crate::test::reset;
+
     #[test]
     fn test_shell() {
+        reset();
         let err = assert_cli_err!("shell", "tiny@1.0.1");
         assert_snapshot!(err);
         env::set_var("__MISE_DIFF", "");
