@@ -4,7 +4,7 @@ use indicatif::{ProgressBar, ProgressStyle};
 use once_cell::sync::Lazy;
 
 use crate::ui::style;
-use crate::{env, forge, ui};
+use crate::{backend, env, ui};
 
 pub trait SingleReport: Send + Sync {
     fn println(&self, _message: String) {}
@@ -46,13 +46,12 @@ pub struct ProgressReport {
 }
 
 static LONGEST_PLUGIN_NAME: Lazy<usize> = Lazy::new(|| {
-    forge::list()
+    backend::list()
         .into_iter()
         .map(|p| p.id().len())
         .max()
         .unwrap_or_default()
-        .max(15)
-        .min(35)
+        .clamp(15, 35)
 });
 
 fn pad_prefix(w: usize, s: &str) -> String {
@@ -167,10 +166,15 @@ impl SingleReport for VerboseReport {
 
 #[cfg(test)]
 mod tests {
+    use test_log::test;
+
+    use crate::test::reset;
+
     use super::*;
 
     #[test]
     fn test_progress_report() {
+        reset();
         let pr = ProgressReport::new("foo".into());
         pr.set_message("message".into());
         pr.finish_with_message("message".into());
@@ -178,6 +182,7 @@ mod tests {
 
     #[test]
     fn test_progress_report_verbose() {
+        reset();
         let pr = VerboseReport::new("PREFIX".to_string());
         pr.set_message("message".into());
         pr.finish_with_message("message".into());
@@ -185,6 +190,7 @@ mod tests {
 
     #[test]
     fn test_progress_report_quiet() {
+        reset();
         let pr = QuietReport::new();
         pr.set_message("message".into());
         pr.finish_with_message("message".into());
